@@ -75,7 +75,7 @@ class FormatMenu:
             if iter_:
                 markup = self.FORMAT_TO_MARKUP[format_]
                 text = self.main_window.categories_tree_view.get_iter_value(iter_)
-                text = "{}{}{}".format(markup, text, markup)
+                text = f"{markup}{text}{markup}"
                 self.main_window.categories_tree_view.set_iter_value(iter_, text)
             else:
                 self.main_window.day_text_field.apply_format(format_)
@@ -129,7 +129,7 @@ class FormatMenu:
             (
                 "Clear",
                 None,
-                _("Clear format") + shortcut("R"),
+                _("Clear Format") + shortcut("R"),
                 "<Control>R",
                 None,
                 self.on_clear_format,
